Function shrimple_parser::parse_until_exact
source · pub fn parse_until_exact(delimiter: &str) -> impl Parser<'_, &str>Expand description
Strips characters from the input until delimiter is met, returns the string before it.
The delimiter is omitted from both the output and the rest of the input.
Errors
The returned parser returns a recoverable error if delimiter isn’t found in the input.