Function shrimple_parser::parse_while

source ·
pub fn parse_while<'input>(
    pred: impl Fn(&char) -> bool
) -> impl Parser<'input, &'input str>
The output is a string up to the point where pred returned true any returned error is recoverable