Function shrimple_parser::parse_while_ex

source ·
pub fn parse_while_ex<'input>(
    pred: impl Fn(&char) -> bool
) -> impl Parser<'input, &'input str>
Like parse_while, but also removes the character on which pred returned false from the rest of the input.

Errors

Unlike parse_while, this parser returns a recoverable error if pred returned true for all the characters in the input.