until_ex

Function until_ex 

pub fn until_ex<In: Input, Reason>(
    pat: impl IntoPattern,
) -> impl Parser<In, In, Reason>
Like until, but also removes the match of pat from the rest of the input.

Errors

Unlike until, this parser returns a recoverable error if pred returned false for all the characters in the input.