pub fn parse_while<In: Input, Reason>(
pat: impl Pattern,
) -> impl Parser<In, In, Reason>Expand description
Parses contiguous instances of pattern pat.
The returned parser never returns an error, if no matches are found at the start of the input, the returned string is empty (but also points to the start of the input)
See also parse_until, parse_until_ex.