Chain

Struct Chain 

pub struct Chain<P1: Pattern, P2: Pattern>(pub P1, pub P2);
A pattern that matches P1 immediately followed by P2.

A match is only produced when both patterns match consecutively at the same position: P1 at the current position and P2 right after it. The combined match spans the entirety of both sub-matches.

Note

For first_match / first_match_ex, every occurrence of P1 in the input is tried in left-to-right order; the first one where P2 immediately follows is returned. Occurrences of P1 that are not followed by P2 are skipped.

More conveniently created via Pattern::and.

Example

use {
    shrimple_parser::{
        Pattern,
        parser::{one, until_ex},
        pattern::{ascii_digit, alphabetic, Chain},
    },
    core::convert::Infallible,
};

// Matches a digit immediately followed by an alphabetic character.
assert_eq!(
    one::<_, Infallible>(ascii_digit.and(alphabetic))("3x rest"),
    Ok((" rest", "3x")),
);

// Returns an error when the pattern is not at the start.
assert!(
    one::<_, Infallible>(ascii_digit.and(alphabetic))("x3 rest")
        .is_err()
);

// Finds the first '$' that is immediately followed by '{'.
assert_eq!(
    until_ex::<_, Infallible>('$'.and('{'))("foo${bar}"),
    Ok(("bar}", "foo")),
);

Tuple Fields

0: P11: P2