pub struct NotEnclosed<Enclosure: Pattern, Inner: Pattern>(pub Enclosure, pub Inner);Expand description
Pattern that matches pattern Inner not surrounded by Enclosure.
Tuple Fields
0: Enclosure1: InnerTrait Implementations
Sourceimpl<Enclosure: Pattern, Inner: Pattern> Pattern for NotEnclosed<Enclosure, Inner>
impl<Enclosure: Pattern, Inner: Pattern> Pattern for NotEnclosed<Enclosure, Inner>
Sourcefn immediate_match<I: Input>(&self, input: I) -> Result<(I, I), I>
fn immediate_match<I: Input>(&self, input: I) -> Result<(I, I), I>
The return values are (rest of the input, matched fragment at the beginning). Read more
Sourcefn immediate_matches<I: Input>(&self, input: I) -> (I, I)
fn immediate_matches<I: Input>(&self, input: I) -> (I, I)
The return values are (rest of the input, contiguous matched fragments from the beginning). Read more
Sourcefn trailing_match<I: Input>(&self, input: I) -> Result<(I, I), I>
fn trailing_match<I: Input>(&self, input: I) -> Result<(I, I), I>
Like
Pattern::immediate_match, but matches at the end of input.
The return values are (the input before the match, the match) Read moreSourcefn first_match<I: Input>(&self, input: I) -> Result<(I, (I, I)), I>
fn first_match<I: Input>(&self, input: I) -> Result<(I, (I, I)), I>
The return values are (the match + rest of the input, (string before the match, the match)). Read more
Sourcefn first_match_ex<I: Input>(&self, input: I) -> Result<(I, (I, I)), I>
fn first_match_ex<I: Input>(&self, input: I) -> Result<(I, (I, I)), I>
Like
Pattern::first_match, but the match is excluded from the rest of the input. Read moreSourcefn immediate_matches_counted<I: Input>(&self, input: I) -> (I, (I, usize))
fn immediate_matches_counted<I: Input>(&self, input: I) -> (I, (I, usize))
Like
Pattern::immediate_matches, but also counts the number of matches. Read moreSourcefn trailing_matches_counted<I: Input>(&self, input: I) -> (I, usize)
fn trailing_matches_counted<I: Input>(&self, input: I) -> (I, usize)
Like
Pattern::immediate_matches_counted, but matches at the end of input,
and doesn’t return the matched fragment of the input. Read moreSourcefn by_ref(&self) -> Ref<'_, Self>
fn by_ref(&self) -> Ref<'_, Self>
Get the pattern by reference to avoid moving it, which will happen in generic code Read more
Sourcefn or<Other: Pattern>(self, other: Other) -> Union<Self, Other>where
Self: Sized,
fn or<Other: Pattern>(self, other: Other) -> Union<Self, Other>where
Self: Sized,
Combine
self and another pattern into a pattern that matches either of them in a
short-circuiting manner, with self tried first. Read moreSourcefn not_escaped_by<Prefix: Pattern>(
self,
prefix: Prefix,
) -> NotEscaped<Prefix, Self>where
Self: Sized,
fn not_escaped_by<Prefix: Pattern>(
self,
prefix: Prefix,
) -> NotEscaped<Prefix, Self>where
Self: Sized,
Create a pattern that’ll match
self only if it’s not escaped (immediately preceded)
by the provided pattern.Sourcefn not_enclosed_by<Enclosure: Pattern>(
self,
enc: Enclosure,
) -> NotEnclosed<Enclosure, Self>where
Self: Sized,
fn not_enclosed_by<Enclosure: Pattern>(
self,
enc: Enclosure,
) -> NotEnclosed<Enclosure, Self>where
Self: Sized,
Create a pattern that’ll match
self only if it’s not enclosed (preceded & superceded) by
the provided pattern.Auto Trait Implementations
impl<Enclosure, Inner> Freeze for NotEnclosed<Enclosure, Inner>
impl<Enclosure, Inner> RefUnwindSafe for NotEnclosed<Enclosure, Inner>where
Enclosure: RefUnwindSafe,
Inner: RefUnwindSafe,
impl<Enclosure, Inner> Send for NotEnclosed<Enclosure, Inner>
impl<Enclosure, Inner> Sync for NotEnclosed<Enclosure, Inner>
impl<Enclosure, Inner> Unpin for NotEnclosed<Enclosure, Inner>
impl<Enclosure, Inner> UnwindSafe for NotEnclosed<Enclosure, Inner>where
Enclosure: UnwindSafe,
Inner: UnwindSafe,