Struct NotEscaped

pub struct NotEscaped<Prefix, Inner>(pub Prefix, pub Inner);
Pattern that matches pattern Inner not escaped by Prefix. “escaped” here means that the pattern Inner is preceded by an odd number of contiguous Prefixes.

For example, for a pattern NotEscaped('\', '0'), the strings “0”, “\0” & “\\\0” will have a match, but the strings “\0”, “\ \0” & “\\\\0” won’t.

Tuple Fields

0: Prefix1: Inner