Struct Union

pub struct Union<P1: Pattern, P2: Pattern>(pub P1, pub P2);
A pattern that matches either of the 2 patterns in a short-circuiting manner, with self tried first. May be created by Pattern::or for convenience.

Note

If you want to match either of N chars, use an array of them as a pattern instead, as this struct has a general impl that may miss optimisations applicable to the case of [char; N] being the pattern. However, unlike the array pattern, the combination of patterns using this struct is not commutative, since the second pattern is only tried if the former has not been found in the input.

Tuple Fields

0: P11: P2