pub trait IntoPattern {
type Pattern: Pattern;
// Required method
fn into_pattern(self) -> Self::Pattern;
}Expand description
A trait for converting values into patterns. It exists to bridge the gap between an easy to use library & a more performant, lean implementation.
All parsers that accept patterns for matching should accept IntoPattern values for better
ergonomics
Required Associated Types
Required Methods
Sourcefn into_pattern(self) -> Self::Pattern
fn into_pattern(self) -> Self::Pattern
Converts the value into a pattern.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".