Struct shrimple_parser::FullParsingError

source ·
pub struct FullParsingError<'path, Reason> {
    pub loc: FullLocation<'path>,
    pub reason: Option<Reason>,
}
A final error with information about where in the source did the error occur.

This should be constructed at the top-level of a parser as the final action before returning the result. Main ways to construct this are ParsingError::with_src_loc and Parser::with_full_error

To print the source line of the error along with the reason & location, wrap the error in WithSourceLine, this will alter its Display implementation.

Fields

loc: FullLocation<'path>

Where the error occured.

reason: Option<Reason>

What the parser expected to see at the location of the error. If None, then the error was recoverable and the parser didn’t have any particular reason.