pub fn first_ref<T: Index<0>>(tuple: &T) -> &T::NthExpand description
Returns a reference to the first element of the tuple.
For a more generic function, see Tuple::nth_ref
pub fn first_ref<T: Index<0>>(tuple: &T) -> &T::NthReturns a reference to the first element of the tuple.
For a more generic function, see Tuple::nth_ref