pub fn third_ref<T: Index<2>>(tuple: &T) -> &T::NthExpand description
Returns a reference to the third element of the tuple.
For a more generic function, see Tuple::nth_ref
pub fn third_ref<T: Index<2>>(tuple: &T) -> &T::NthReturns a reference to the third element of the tuple.
For a more generic function, see Tuple::nth_ref