Struct shrimple_parser::utils::FullLocation
source · pub struct FullLocation<'path> {
pub path: &'path Path,
pub loc: Location,
}Expand description
Like Location, but also stores the path to the file.
Fields
path: &'path PathThe path to the file associated with the location.
loc: LocationThe line & column numbers of the location.