Struct shrimple_parser::utils::WithSourceLine
source · pub struct WithSourceLine<T>(pub T);Expand description
A wrapper for FullLocation & crate::FullParsingError that will change their Display
implementations to get the source line from the filesystem and print it in a Rust-like format.
Tuple Fields
0: TTrait Implementations
sourceimpl<T: Clone> Clone for WithSourceLine<T>
impl<T: Clone> Clone for WithSourceLine<T>
sourcefn clone(&self) -> WithSourceLine<T>
fn clone(&self) -> WithSourceLine<T>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<T: Debug> Debug for WithSourceLine<T>
impl<T: Debug> Debug for WithSourceLine<T>
sourceimpl Display for WithSourceLine<FullLocation<'_>>
impl Display for WithSourceLine<FullLocation<'_>>
sourceimpl<Reason: Display> Display for WithSourceLine<FullParsingError<'_, Reason>>
impl<Reason: Display> Display for WithSourceLine<FullParsingError<'_, Reason>>
sourceimpl<T: PartialEq> PartialEq for WithSourceLine<T>
impl<T: PartialEq> PartialEq for WithSourceLine<T>
sourcefn eq(&self, other: &WithSourceLine<T>) -> bool
fn eq(&self, other: &WithSourceLine<T>) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl<T: Copy> Copy for WithSourceLine<T>
impl<T: Eq> Eq for WithSourceLine<T>
impl<T> StructuralPartialEq for WithSourceLine<T>