Function shrimple_parser::parse_until
source · pub fn parse_until<'input>(
pred: impl Fn(&char) -> bool
) -> impl Parser<'input, &'input str>Expand description
Strips characters from the input until pred returns true, i.e. while it returns false.
Returns the consumed string slice or a recoverable error.
See also parse_while