Function shrimple_parser::parse_until_ex
source · pub fn parse_until_ex<'input>(
pred: impl Fn(&char) -> bool
) -> impl Parser<'input, &'input str>Expand description
Like parse_until, but also removes the character on which pred returned true from the
rest of the input.
Errors
Unlike parse_until, this parser returns a recoverable error if pred returned false for
all the characters in the input.