A collection of fundamental parsers to build out your own.
Structs
- Iter
- Iterator returned by
Parser::iter
Traits
- Mapping
Parser - A trait alias for a function that maps from the input & intermediate output to the rest of the input & a different output.
- Parser
- A trait representing a function that takes some string-like input and
returns either a tuple of (the rest of the input, the output) or a
ParsingError.
Functions
- group
- Parse a balanced group of
open&closepatterns. - group_
ex - Parse a balanced group of
open&closepatterns. - many
- Parses contiguous instances of pattern
pat. - one
- Parses 1 instance of pattern
pat. - ready
- Returns a parser that always returns the provided value.
- until
- Parses a span of the input until a match of pattern
patis met. - until_
ex - Like
until, but also removes the match ofpatfrom the rest of the input.