pub fn many<In: Input, Reason>( pat: impl IntoPattern, ) -> impl Parser<In, In, Reason>
Parses contiguous instances of pattern pat.
pat
The returned parser never returns an error, if no matches are found at the start of the input, the returned string is empty (but also points to the start of the input)
See also until, until_ex.
until
until_ex