Abstractions for working with patterns.
Structs
- AnyChar
- A pattern that matches anything.
- NotEscaped
- Pattern that matches pattern
Innernot escaped byPrefix. “escaped” here means that the patternInneris preceded by an odd number of contiguousPrefixes.
Traits
- Pattern
- This trait represents an object that can be matched onto a string.
This includes functions, characters, [arrays of] characters, strings, but also custom patterns
like
NotEscaped
Functions
- parse
- Parses 1 instance of pattern
pat. - parse_
group - Parse a balanced group of
open&closepatterns. - parse_
until - Parses a span of the input until a match of pattern
patis met. - parse_
until_ ex - Like
parse_until, but also removes the match ofpatfrom the rest of the input. - parse_
while - Parses contiguous instances of pattern
pat.