Function parse_until

pub fn parse_until<In: Input>(pat: impl Pattern) -> impl Parser<In, In>
Parses a span of the input until a match of pattern pat is met.

The returned rest of the input will still have the match.

The returned parser never returns an error, if pred returns false for all the characters in the input, then the output is the entire input, and the rest of the input is an empty string.

See also parse_while, parse_until_ex.