Function parse_until_ex

pub fn parse_until_ex<In: Input>(pat: impl Pattern) -> impl Parser<In, In>
Like parse_until, but also removes the match of pat from the rest of the input.

Errors

Unlike parse_until, this parser returns a recoverable error if pred returned false for all the characters in the input.