pub struct NotEscaped<Prefix, Inner>(pub Prefix, pub Inner);Expand description
Pattern that matches pattern Inner not escaped by Prefix.
“escaped” here means that the pattern Inner is preceded by an odd number
of contiguous Prefixes.
For example, for a pattern NotEscaped('\', '0'), the strings “0”, “\0” & “\\\0” will have
a match, but the strings “\0”, “\ \0” & “\\\\0” won’t.
Tuple Fields
0: Prefix1: InnerTrait Implementations
Sourceimpl<Prefix: Pattern, Inner: Pattern> Pattern for NotEscaped<Prefix, Inner>
impl<Prefix: Pattern, Inner: Pattern> Pattern for NotEscaped<Prefix, Inner>
Sourcefn immediate_match<I: Input>(&self, input: I) -> Result<(I, I), I>
fn immediate_match<I: Input>(&self, input: I) -> Result<(I, I), I>
The return values are (rest of the input, matched fragment at the beginning). Read more
Sourcefn trailing_match<I: Input>(&self, input: I) -> Result<(I, I), I>
fn trailing_match<I: Input>(&self, input: I) -> Result<(I, I), I>
Like
Pattern::immediate_match, but matches at the end of input.
The return values are (the input before the match, the match) Read moreSourcefn trailing_matches_counted<I: Input>(&self, input: I) -> (I, usize)
fn trailing_matches_counted<I: Input>(&self, input: I) -> (I, usize)
Like
Pattern::immediate_matches_counted, but matches at the end of input,
and doesn’t return the matched fragment of the input. Read moreSourcefn first_match<I: Input>(&self, input: I) -> Result<(I, (I, I)), I>
fn first_match<I: Input>(&self, input: I) -> Result<(I, (I, I)), I>
The return values are (the match + rest of the input, (string before the match, the match)). Read more
Sourcefn first_match_ex<I: Input>(&self, input: I) -> Result<(I, (I, I)), I>
fn first_match_ex<I: Input>(&self, input: I) -> Result<(I, (I, I)), I>
Like
Pattern::first_match, but the match is excluded from the rest of the input. Read moreSourcefn immediate_matches<I: Input>(&self, input: I) -> (I, I)
fn immediate_matches<I: Input>(&self, input: I) -> (I, I)
The return values are (rest of the input, contiguous matched fragments from the beginning). Read more
Sourcefn immediate_matches_counted<I: Input>(&self, input: I) -> (I, (I, usize))
fn immediate_matches_counted<I: Input>(&self, input: I) -> (I, (I, usize))
Like
Pattern::immediate_matches, but also counts the number of matches. Read moreAuto Trait Implementations
impl<Prefix, Inner> Freeze for NotEscaped<Prefix, Inner>
impl<Prefix, Inner> RefUnwindSafe for NotEscaped<Prefix, Inner>where
Prefix: RefUnwindSafe,
Inner: RefUnwindSafe,
impl<Prefix, Inner> Send for NotEscaped<Prefix, Inner>
impl<Prefix, Inner> Sync for NotEscaped<Prefix, Inner>
impl<Prefix, Inner> Unpin for NotEscaped<Prefix, Inner>
impl<Prefix, Inner> UnwindSafe for NotEscaped<Prefix, Inner>where
Prefix: UnwindSafe,
Inner: UnwindSafe,